#
# spec file for package hledger-ui
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name hledger-ui
%global pkgver %{pkg_name}-%{version}
Name:           %{pkg_name}
Version:        1.41
Release:        2.1
Summary:        Terminal interface for the hledger accounting system
License:        GPL-3.0-or-later
URL:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{name}-%{version}/revision/1.cabal#/%{name}.cabal
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-ansi-terminal-devel
BuildRequires:  ghc-ansi-terminal-prof
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-async-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-brick-devel
BuildRequires:  ghc-brick-prof
BuildRequires:  ghc-cmdargs-devel
BuildRequires:  ghc-cmdargs-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-data-default-devel
BuildRequires:  ghc-data-default-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-doclayout-devel
BuildRequires:  ghc-doclayout-prof
BuildRequires:  ghc-extra-devel
BuildRequires:  ghc-extra-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-fsnotify-devel
BuildRequires:  ghc-fsnotify-prof
BuildRequires:  ghc-githash-devel
BuildRequires:  ghc-githash-prof
BuildRequires:  ghc-hledger-devel
BuildRequires:  ghc-hledger-lib-devel
BuildRequires:  ghc-hledger-lib-prof
BuildRequires:  ghc-hledger-prof
BuildRequires:  ghc-megaparsec-devel
BuildRequires:  ghc-megaparsec-prof
BuildRequires:  ghc-microlens-devel
BuildRequires:  ghc-microlens-platform-devel
BuildRequires:  ghc-microlens-platform-prof
BuildRequires:  ghc-microlens-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-process-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-safe-devel
BuildRequires:  ghc-safe-prof
BuildRequires:  ghc-split-devel
BuildRequires:  ghc-split-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-text-zipper-devel
BuildRequires:  ghc-text-zipper-prof
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-time-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-unix-prof
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-vector-prof
BuildRequires:  ghc-vty-crossplatform-devel
BuildRequires:  ghc-vty-crossplatform-prof
BuildRequires:  ghc-vty-devel
BuildRequires:  ghc-vty-prof
ExcludeArch:    %{ix86}

%description
A simple terminal user interface for the hledger accounting system. It can be a
more convenient way to browse your accounts than the CLI. This package
currently does not support Microsoft Windows, except in WSL.

hledger is a robust, cross-platform set of tools for tracking money, time, or
any other commodity, using double-entry accounting and a simple, editable file
format, with command-line, terminal and web interfaces. It is a Haskell rewrite
of Ledger, and one of the leading implementations of Plain Text Accounting.
Read more at: <https://hledger.org>.

%package -n ghc-%{name}
Summary:        Haskell %{name} library

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.

%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Requires:       ghc-%{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup
cp -p %{SOURCE1} %{name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%post -n ghc-%{name}-devel
%ghc_pkg_recache

%postun -n ghc-%{name}-devel
%ghc_pkg_recache

%files
%license LICENSE
%doc CHANGES.md README.md
%{_bindir}/%{name}

%files -n ghc-%{name} -f ghc-%{name}.files
%license LICENSE

%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%doc CHANGES.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Fri Jan 31 2025 Peter Simons <psimons@suse.com>
- Update hledger-ui to version 1.41 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Dec 10 2024 Peter Simons <psimons@suse.com>
- Update hledger-ui to version 1.41.
  Upstream's change log file format is strange (too much unmodified
  text at at the top). The automatic updater cannot extract the
  relevant additions. You can find the file at:
  http://hackage.haskell.org/package/hledger-ui-1.41/src/CHANGES.md
* Mon Sep  9 2024 Peter Simons <psimons@suse.com>
- Update hledger-ui to version 1.40.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/hledger-ui-1.40/src/CHANGES.md
* Fri Jul 12 2024 Peter Simons <psimons@suse.com>
- Update hledger-ui to version 1.34 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Jun  2 2024 Peter Simons <psimons@suse.com>
- Update hledger-ui to version 1.34.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/hledger-ui-1.34/src/CHANGES.md
* Sat May 18 2024 Peter Simons <psimons@suse.com>
- Update hledger-ui to version 1.33.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu May  2 2024 Peter Simons <psimons@suse.com>
- Update hledger-ui to version 1.33.1.
  Upstream's change log file format is strange (too much unmodified
  text at at the top). The automatic updater cannot extract the
  relevant additions. You can find the file at:
  http://hackage.haskell.org/package/hledger-ui-1.33.1/src/CHANGES.md
* Thu Apr 18 2024 Peter Simons <psimons@suse.com>
- Update hledger-ui to version 1.33.
  Upstream's change log file format is strange (too much unmodified
  text at at the top). The automatic updater cannot extract the
  relevant additions. You can find the file at:
  http://hackage.haskell.org/package/hledger-ui-1.33/src/CHANGES.md
- Drop obsolete "fix-build-with-ghc-9.8.x.patch".
* Wed Feb 28 2024 Peter Simons <psimons@suse.com>
- Apply "fix-build-with-ghc-9.8.x.patch" to fix the build with
  base library version 4.19.x.
* Sun Jan 28 2024 Peter Simons <psimons@suse.com>
- Update hledger-ui to version 1.32.3.
  Upstream's change log file format is strange (too much unmodified
  text at at the top). The automatic updater cannot extract the
  relevant additions. You can find the file at:
  http://hackage.haskell.org/package/hledger-ui-1.32.3/src/CHANGES.md
* Mon Jan  1 2024 Peter Simons <psimons@suse.com>
- Update hledger-ui to version 1.32.2.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/hledger-ui-1.32.2/src/CHANGES.md
* Thu Dec  7 2023 Peter Simons <psimons@suse.com>
- Update hledger-ui to version 1.32.1.
  Upstream's change log file format is strange (too much unmodified
  text at at the top). The automatic updater cannot extract the
  relevant additions. You can find the file at:
  http://hackage.haskell.org/package/hledger-ui-1.32.1/src/CHANGES.md
* Sat Dec  2 2023 Peter Simons <psimons@suse.com>
- Update hledger-ui to version 1.32.
  - The V key now preserves the valuation mode specified at the
    command line, if any. (#2084)
  - The hledger-ui package no longer wastefully builds its modules
    twice.
* Sun Sep  3 2023 Peter Simons <psimons@suse.com>
- Update hledger-ui to version 1.31.
  - A "Cash accounts" screen has been added, showing accounts of
    the `Cash` type.
  - The top-level menu screen is now the default screen. Power
    users can use the `--cash`/`--bs`/`--is`/`--all` flags to start
    up in another screen.
  - "All accounts" screen has been moved to the bottom of the list.
  - Screens' help footers have been improved.
  - A pager is used to show --help output when needed, as in
    `hledger`.
  - In the help dialog, mention that LEFT shows other screens.
  - In the manual, mention shift-up/down config needed for
    Terminal.app.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Thu Dec  1 2022 Peter Simons <psimons@suse.com>
- Update hledger-ui to version 1.28.
  Upstream's change log file format is strange (too much unmodified
  text at at the top). The automatic updater cannot extract the
  relevant additions. You can find the file at:
  http://hackage.haskell.org/package/hledger-ui-1.28/src/CHANGES.md
* Sun Sep 18 2022 Peter Simons <psimons@suse.com>
- Update hledger-ui to version 1.27.1.
  Upstream has not updated the file "CHANGES.md" since the last
  release.
* Fri Sep  2 2022 Peter Simons <psimons@suse.com>
- Update hledger-ui to version 1.27.
  Upstream's change log file format is strange (too much unmodified
  text at at the top). The automatic updater cannot extract the
  relevant additions. You can find the file at:
  http://hackage.haskell.org/package/hledger-ui-1.27/src/CHANGES.md
* Sun Aug 14 2022 Peter Simons <psimons@suse.com>
- Update hledger-ui to version 1.26.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Jul 11 2022 Peter Simons <psimons@suse.com>
- Update hledger-ui to version 1.26.1.
  Upstream's change log file format is strange (too much unmodified
  text at at the top). The automatic updater cannot extract the
  relevant additions. You can find the file at:
  http://hackage.haskell.org/package/hledger-ui-1.26.1/src/CHANGES.md
* Fri Jun 10 2022 Peter Simons <psimons@suse.com>
- Update hledger-ui to version 1.26 revision 1.
  Upstream's change log file format is strange (too much unmodified
  text at at the top). The automatic updater cannot extract the
  relevant additions. You can find the file at:
  http://hackage.haskell.org/package/hledger-ui-1.26/src/CHANGES.md
* Sat Mar  5 2022 Peter Simons <psimons@suse.com>
- Update hledger-ui to version 1.25.
  Upstream's change log file format is strange (too much unmodified
  text at at the top). The automatic updater cannot extract the
  relevant additions. You can find the file at:
  http://hackage.haskell.org/package/hledger-ui-1.25/src/CHANGES.md
* Fri Dec 10 2021 Peter Simons <psimons@suse.com>
- Update hledger-ui to version 1.24.99.
  Upstream's change log file format is strange (too much unmodified
  text at at the top). The automatic updater cannot extract the
  relevant additions. You can find the file at:
  http://hackage.haskell.org/package/hledger-ui-1.24.99/src/CHANGES.md
* Thu Oct  7 2021 psimons@suse.com
- Update hledger-ui to version 1.23 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Sep 22 2021 psimons@suse.com
- Update hledger-ui to version 1.23.
  Upstream's change log file format is strange (too much unmodified
  text at at the top). The automatic updater cannot extract the
  relevant additions. You can find the file at:
  http://hackage.haskell.org/package/hledger-ui-1.23/src/CHANGES.md
* Tue Sep  7 2021 Ondřej Súkup <mimi.vx@gmail.com>
- relax constranits on base-compat
* Sun Aug  8 2021 psimons@suse.com
- Update hledger-ui to version 1.22.2.
  Upstream's change log file format is strange (too much unmodified
  text at at the top). The automatic updater cannot extract the
  relevant additions. You can find the file at:
  http://hackage.haskell.org/package/hledger-ui-1.22.2/src/CHANGES.md
* Wed Aug  4 2021 psimons@suse.com
- Update hledger-ui to version 1.22.1.
  Upstream's change log file format is strange (too much unmodified
  text at at the top). The automatic updater cannot extract the
  relevant additions. You can find the file at:
  http://hackage.haskell.org/package/hledger-ui-1.22.1/src/CHANGES.md
* Mon Jul 19 2021 psimons@suse.com
- Update hledger-ui to version 1.22 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Jul 10 2021 psimons@suse.com
- Update hledger-ui to version 1.22.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/hledger-ui-1.22/src/CHANGES.md
* Thu Mar 11 2021 psimons@suse.com
- Update hledger-ui to version 1.21.
  [#] 1.21 2021-03-10
  - Register screen: also show transactions below the depth limit, as in
    1.19, keeping the register balance in agreement with the balance
    shown on the accounts screen. This regressed in 1.20. (#1468)
  - Transaction screen: all decimal places are now shown. On the
    accounts screen and register screen we round amounts according to
    commodity display styles, but when you drill down to a transaction
    you probably want to see the unrounded amounts. (Like print, #cf
    931.)
  - New flags `--man` and `--info` open the man page or info manual.
    (See hledger changelog)
* Sun Jan 31 2021 psimons@suse.com
- Update hledger-ui to version 1.20.4.
  [#] 1.20.4 2021-01-29
  - ui: register: show all txns in/under an account at the depth limit (#1468).
    In 1.20-1.20.3, the register screen had stopped showing transactions
    in accounts below a depth limit. Now it properly shows all subaccount transactions,
    even when there is a depth limit, ensuring that the register's final total
    matches the balance shown on the account screen.
* Fri Jan 15 2021 psimons@suse.com
- Update hledger-ui to version 1.20.3.
  [#] 1.20.3 2021-01-14
  - Use hledger 1.20.3.
* Tue Dec 29 2020 psimons@suse.com
- Update hledger-ui to version 1.20.2.
  [#] 1.20.2 2020-12-28
  - Fix loss of capitalisation in part of the manual.
  - Fix the info manual's node structure.
  - Use hledger 1.20.2.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Wed Dec 16 2020 psimons@suse.com
- Update hledger-ui to version 1.20.1.
  [#] 1.20.1 2020-12-15
  - Fix the F key (toggle future/forecast transactions), which in 1.20
    would only work twice. (#1411)
  - Fix loss of forecasted transactions when the journal was reloaded
    while they were hidden. (#1204)
* Sun Dec  6 2020 psimons@suse.com
- Update hledger-ui to version 1.20.
  [#] 1.20 2020-12-05
  - When entering a query with `/`, malformed queries/regular expressions
    no longer cause the program to exit. (Stephen Morgan)
  - Eliding of multicommodity amounts now makes better use of available space. (Stephen Morgan)
  - `E` now parses the `HLEDGER_UI_EDITOR` or `EDITOR` environment variable
    correctly on Windows (ignoring the file extension), so if you have that set
    it should be better at opening your editor at the correct line.
  - `E` now supports positioning when `HLEDGER_UI_EDITOR` or `EDITOR`
    is VS Code ("`code`") (#1359)
  - hledger-ui now has a (human-powered) test suite.
* Tue Sep  8 2020 psimons@suse.com
- Update hledger-ui to version 1.19.1.
  [#] 1.19.1 2020-09-07
  - Allow megaparsec 9
* Thu Sep  3 2020 psimons@suse.com
- Update hledger-ui to version 1.19.
  [#] 1.19 2020-09-01
  - The --color/--colour=WHEN command line option, support for the
    NO_COLOR environment variable, and smarter autodetection of colour
    terminals have been added (#1296)
  - -t and -l command line flags have been added as short forms of
  - -tree and --flat (#1286)
  - Flat (AKA list) mode is now the default
  - t now toggles tree mode, while T sets the "today" period (#1286)
  - register: multicommodity amounts containing more than two
    commodities are now elided
  - register: a transaction dated outside the report period now is not
    shown even if it has postings dated inside the report period.
  - ESC now restores exactly the app's state at startup, which includes
    clearing any report period limit (#1286)
  - DEL/BS no longer changes the tree/list mode
  - q now exits help before exiting the app (#1286)
  - The help dialog's layout is improved
* Wed Aug 19 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints with 6GB min disk space for ppc64/ppc64le
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Mon Jun 22 2020 psimons@suse.com
- Update hledger-ui to version 1.18.1.
  [#] 1.18.1 2020-06-21
  - Fix regression in 'F' (#1255) (Dmitry Astapov)
* Tue Jun  9 2020 psimons@suse.com
- Add hledger-ui at version 1.18.
